@@ -1,24 +1,23 @@
 /*
-    GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2001  Ales Cepek <cepek@fsv.cvut.cz>,
-                        Jan Pytel <jan.pytel@gmail.com>,
-                  2010, 2013  Ales Cepek <cepek@gnu.org>
+  GNU Gama -- adjustment of geodetic networks
+  Copyright (C) 2001  Ales Cepek <cepek@fsv.cvut.cz>,
+                      Jan Pytel <jan.pytel@gmail.com>,
+                2010, 2013, 2018  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ library.
+  This file is part of the GNU Gama C++ library.
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  You should have received a copy of the GNU General Public License
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <gnu_gama/local/local_revision.h>
@@ -33,18 +32,18 @@ void LocalLinearization::direction(const Direction* obs) const
 {
    LocalPoint& sbod = PD[obs->from()];
    LocalPoint& cbod = PD[obs->to()];
-   Double s, d;
+   double s, d;
    bearing_distance(sbod, cbod, s, d);
-   // const Double p = m0 / obs->stdDev();
-   const Double K = 10*R2G/d;
-   const Double ps = K*sin(s);
-   const Double pc = K*cos(s);
+   // const double p = m0 / obs->stdDev();
+   const double K = 10*R2G/d;
+   const double ps = K*sin(s);
+   const double pc = K*cos(s);
 
    const StandPoint*  csp = static_cast<const StandPoint*>(obs->ptr_cluster());
    StandPoint* sp = const_cast<StandPoint*>(csp);
 
-   // Double w = p*p;                                       // weight
-   Double a = (obs->value() + sp->orientation() - s)*R2CC;  // rhs
+   // double w = p*p;                                       // weight
+   double a = (obs->value() + sp->orientation() - s)*R2CC;  // rhs
 
    while (a > 200e4)
       a -= 400e4;
@@ -86,13 +85,13 @@ void LocalLinearization::distance(const Distance* obs) const
 {
    LocalPoint& sbod = PD[obs->from()];
    LocalPoint& cbod = PD[obs->to()];
-   Double s, d;
+   double s, d;
    bearing_distance(PD[obs->from()], PD[obs->to()], s, d);
-   // Double p = M_0 / stdDev();
-   Double ps = sin(s);
-   Double pc = cos(s);
+   // double p = M_0 / stdDev();
+   double ps = sin(s);
+   double pc = cos(s);
 
-   // Double w = p*p;                  // weight
+   // double w = p*p;                  // weight
    rhs = (obs->value() - d)*1e3;       // abs. term in millimetres
 
    size = 0;
@@ -125,10 +124,10 @@ void LocalLinearization::h_diff(const H_Diff* obs) const
 {
    LocalPoint& sbod = PD[obs->from()];
    LocalPoint& cbod = PD[obs->to()];
-   Double h = cbod.z() - sbod.z();
-   // Double p = M_0 / stdDev();
+   double h = cbod.z() - sbod.z();
+   // double p = M_0 / stdDev();
 
-   // Double w = p*p;                  // weight
+   // double w = p*p;                  // weight
    rhs = (obs->value() - h)*1e3;       // abs. term in millimetres
 
    size = 0;
@@ -153,21 +152,21 @@ void LocalLinearization::s_distance(const S_Distance* obs) const
 {
    LocalPoint& sbod = PD[obs->from()];
    LocalPoint& cbod = PD[obs->to()];
-   // Double s, sd;
+   // double s, sd;
    // bearing_sdistance(PD[obs->from()], PD[obs->to()], s, sd);
-   // Double p = M_0 / stdDev();
-   Double dx = cbod.x() - sbod.x();
-   Double dy = cbod.y() - sbod.y();
-   Double dz = cbod.z() - sbod.z();
-   Double sd = sqrt(dx*dx + dy*dy + dz*dz);
+   // double p = M_0 / stdDev();
+   double dx = cbod.x() - sbod.x();
+   double dy = cbod.y() - sbod.y();
+   double dz = cbod.z() - sbod.z();
+   double sd = sqrt(dx*dx + dy*dy + dz*dz);
    if (sd == 0)
      throw GNU_gama::local::Exception(T_POBS_zero_or_negative_slope_distance);
 
-   Double px = dx / sd;
-   Double py = dy / sd;
-   Double pz = dz / sd;
+   double px = dx / sd;
+   double py = dy / sd;
+   double pz = dz / sd;
 
-   // Double w = p*p;                // weight
+   // double w = p*p;                // weight
    rhs = (obs->value() - sd)*1e3;    // abs. term in millimetres
 
    size = 0;
@@ -213,9 +212,9 @@ void LocalLinearization::s_distance(const S_Distance* obs) const
 void LocalLinearization::x(const X* obs) const
 {
    LocalPoint& point = PD[obs->from()];
-   // Double p = M_0 / stdDev();
+   // double p = M_0 / stdDev();
 
-   // Double w = p*p;                          // weight
+   // double w = p*p;                          // weight
    rhs = (obs->value() - point.x())*1e3;       // abs. term in millimetres
 
    size = 0;
@@ -232,9 +231,9 @@ void LocalLinearization::x(const X* obs) const
 void LocalLinearization::y(const Y* obs) const
 {
    LocalPoint& point = PD[obs->from()];
-   // Double p = M_0 / stdDev();
+   // double p = M_0 / stdDev();
 
-   // Double w = p*p;                          // weight
+   // double w = p*p;                          // weight
    rhs = (obs->value() - point.y())*1e3;       // abs. term in millimetres
 
    size = 0;
@@ -251,9 +250,9 @@ void LocalLinearization::y(const Y* obs) const
 void LocalLinearization::z(const Z* obs) const
 {
    LocalPoint& point = PD[obs->from()];
-   // Double p = M_0 / stdDev();
+   // double p = M_0 / stdDev();
 
-   // Double w = p*p;                          // weight
+   // double w = p*p;                          // weight
    rhs = (obs->value() - point.z())*1e3;       // abs. term in millimetres
 
    size = 0;
@@ -271,10 +270,10 @@ void LocalLinearization::xdiff(const Xdiff* obs) const
 {
   LocalPoint& spoint = PD[obs->from()];               // stand point
   LocalPoint& tpoint = PD[obs-> to() ];               // target
-  Double df = tpoint.x() - spoint.x();
-  // Double p  = M_0 / stdDev();
+  double df = tpoint.x() - spoint.x();
+  // double p  = M_0 / stdDev();
 
-  // Double w = p*p;                             // weight
+  // double w = p*p;                             // weight
   rhs = (obs->value() - df)*1e3;                 // abs. term in millimetres
 
   size = 0;
@@ -299,10 +298,10 @@ void LocalLinearization::ydiff(const Ydiff* obs) const
 {
   LocalPoint& spoint = PD[obs->from()];
   LocalPoint& tpoint = PD[obs-> to() ];
-  Double df = tpoint.y() - spoint.y();
-  // Double p = M_0 / stdDev();
+  double df = tpoint.y() - spoint.y();
+  // double p = M_0 / stdDev();
 
-  // Double w = p*p;
+  // double w = p*p;
   rhs = (obs->value() - df)*1e3;
 
   size = 0;
@@ -327,10 +326,10 @@ void LocalLinearization::zdiff(const Zdiff* obs) const
 {
   LocalPoint& spoint = PD[obs->from()];
   LocalPoint& tpoint = PD[obs-> to() ];
-  Double df = tpoint.z() - spoint.z();
-  // Double p = M_0 / stdDev();
+  double df = tpoint.z() - spoint.z();
+  // double p = M_0 / stdDev();
 
-  // Double w = p*p;
+  // double w = p*p;
   rhs = (obs->value() - df)*1e3;
 
   size = 0;
@@ -355,32 +354,32 @@ void LocalLinearization::z_angle(const Z_Angle* obs) const
 {
    LocalPoint& sbod = PD[obs->from()];
    LocalPoint& cbod = PD[obs->to()];
-   // Double s, d, sd;
+   // double s, d, sd;
    // bearing_distance(PD[obs->from()], PD[obs->to()], s, d);
    // bearing_sdistance(PD[obs->from()], PD[obs->to()], s, sd);
 
-   Double dx = cbod.x() - sbod.x();
-   Double dy = cbod.y() - sbod.y();
-   Double dz = cbod.z() - sbod.z();
+   double dx = cbod.x() - sbod.x();
+   double dy = cbod.y() - sbod.y();
+   double dz = cbod.z() - sbod.z();
 
-   Double d2 = dx*dx + dy*dy;
-   Double d  = sqrt(d2);
-   Double sd = sqrt(d2 + dz*dz);
+   double d2 = dx*dx + dy*dy;
+   double d  = sqrt(d2);
+   double sd = sqrt(d2 + dz*dz);
    if (d == 0 || sd == 0)
      throw GNU_gama::local::Exception(T_POBS_zero_or_negative_zenith_angle);
 
-   Double k  = 10*R2G/(d*sd*sd);
+   double k  = 10*R2G/(d*sd*sd);
 
-   // Double p = M_0 / stdDev();
-   Double px =  k * dz * dx;
-   Double py =  k * dz * dy;
-   Double pz = -k *  d *  d;
-   // Double w = p*p;                  // weight
+   // double p = M_0 / stdDev();
+   double px =  k * dz * dx;
+   double py =  k * dz * dy;
+   double pz = -k *  d *  d;
+   // double w = p*p;                  // weight
 
-   Double za = acos(dz/sd);
+   double za = acos(dz/sd);
 
    if (obs->value() > M_PI) za = 2*M_PI - za;
-   Double a  = (obs->value() - za);
+   double a  = (obs->value() - za);
 
    rhs = a * R2CC; // abs. term in cc
    size = 0;
@@ -428,21 +427,21 @@ void LocalLinearization::angle(const Angle* obs) const
    LocalPoint& sbod  = PD[obs->from()];
    LocalPoint& cbod1 = PD[obs->bs()];
    LocalPoint& cbod2 = PD[obs->fs()];
-   Double s1, d1, s2, d2;
+   double s1, d1, s2, d2;
    bearing_distance(PD[obs->from()], PD[obs->bs()], s1, d1);
    bearing_distance(PD[obs->from()], PD[obs->fs()], s2, d2);
-   // Double p = m0 / obs->stdDev();
-   const Double K1 = 10*R2G/d1;
-   const Double K2 = 10*R2G/d2;
-   const Double ps1 = K1*sin(s1);
-   const Double pc1 = K1*cos(s1);
-   const Double ps2 = K2*sin(s2);
-   const Double pc2 = K2*cos(s2);
+   // double p = m0 / obs->stdDev();
+   const double K1 = 10*R2G/d1;
+   const double K2 = 10*R2G/d2;
+   const double ps1 = K1*sin(s1);
+   const double pc1 = K1*cos(s1);
+   const double ps2 = K2*sin(s2);
+   const double pc2 = K2*cos(s2);
 
-   // Double w = p*p;                          // weight
-   Double ds = s2 - s1;
+   // double w = p*p;                          // weight
+   double ds = s2 - s1;
    if (ds < 0) ds += 2*M_PI;
-   Double a = (obs->value() - ds)*R2CC;        // rhs
+   double a = (obs->value() - ds)*R2CC;        // rhs
    // "big" positive/negative angle transformed to "lesser" positive/negative
    while (a > 200e4)
       a -= 400e4;
@@ -491,16 +490,16 @@ void LocalLinearization::azimuth(const Azimuth* obs) const
 {
    LocalPoint& sbod = PD[obs->from()];
    LocalPoint& cbod = PD[obs->to()];
-   Double s, d;
+   double s, d;
    bearing_distance(sbod, cbod, s, d);
-   const Double K = 10*R2G/d;
-   const Double ps = K*sin(s);
-   const Double pc = K*cos(s);
+   const double K = 10*R2G/d;
+   const double ps = K*sin(s);
+   const double pc = K*cos(s);
 
    // const StandPoint*  csp = static_cast<const StandPoint*>(obs->ptr_cluster()); ... unused
    // StandPoint* sp = const_cast<StandPoint*>(csp); ... unused
 
-   Double a = (obs->value() + PD.xNorthAngle() - s)*R2CC;  // rhs
+   double a = (obs->value() + PD.xNorthAngle() - s)*R2CC;  // rhs
 
    while (a > 200e4)
       a -= 400e4;
