@@ -1,22 +1,21 @@
 /*
-    GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2002, 2005  Ales Cepek <cepek@gnu.org>
+  GNU Gama -- adjustment of geodetic networks
+  Copyright (C) 2002, 2005, 2018  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ library.
+  This file is part of the GNU Gama C++ library.
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  You should have received a copy of the GNU General Public License
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <gnu_gama/xml/dataparser.h>
@@ -49,7 +48,7 @@ DataParser::~DataParser()
 }
 
 
-DataParser::DataParser(List<DataObject::Base*>& obs) : objects(obs)
+DataParser::DataParser(std::list<DataObject::Base*>& obs) : objects(obs)
 {
   adj   = 0;
   g3    = 0;
@@ -372,7 +371,7 @@ DataParser::data_tag DataParser::tag(const char* c)
 
 // *****************************************************************
 
-int DataParser::parser_error(const char *name, const char **atts)
+int DataParser::parser_error(const char *name, const char ** /*atts*/)
 {
   return error(string("### tag <") + string(name)
                + string("> cannot be used in this context"));
@@ -385,7 +384,7 @@ int DataParser::start_tag(const char *name, const char **atts)
   return (state = next[state][tag(name)]);
 }
 
-int DataParser::end_tag(const char *name)
+int DataParser::end_tag(const char * /*name*/)
 {
   return (state = after[state]);
 }
@@ -413,7 +412,7 @@ int DataParser::white_spaces(const char* s, int len)
 int DataParser::add_text(const char* s, int len)
 {
   text_buffer += ' ';
-  text_buffer += string(s, len);
+  text_buffer += string(s, std::string::size_type(len));
   return 0;
 }
 
